@@ -142,16 +142,7 @@ class UUVMotionSimulator(deeding.LapseDeed):
         self.ionames = dict( speed = None, speedRate = None, bottom = None,
                              pitch = None, pitchRate = None,
                              depth = None, depthRate = None, altitude = None,
-                             heading = None, headingRate = None)
-    
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
+                             heading = None, headingRate = None) 
         
         
     def initio(self, group, speed, speedRate, velocity,
@@ -446,16 +437,6 @@ class USVMotionSimulator(deeding.LapseDeed):
                              heading = None, headingRate = None)
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-                
-    
     def initio(self, group, speed, speedRate,  velocity,
                  heading, headingRate, position,
                  rpm, rudder, current, onset, parms = None, **kw):
@@ -655,15 +636,7 @@ class GPSSensorSimulator(deeding.LapseDeed):
         """
         #call super class method
         super(GPSSensorSimulator,self).__init__(**kw)  
-    
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
+      
                 
     def initio(self, group, positionOut, velocityOut, error,
                  heading, speed,  positionIn, velocityIn, 
@@ -840,16 +813,7 @@ class DVLSensorSimulator(deeding.LapseDeed):
         #call super class method
         super(DVLSensorSimulator,self).__init__(**kw)  
 
-    
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
+
     def initio(self, group, velocity, currentOut, altitude,
                  heading, speed, currentIn, bottom,
                  scenario, parms = None, **kw):
@@ -1021,16 +985,7 @@ class CompassSensorSimulator(deeding.LapseDeed):
         #call super class method
         super(CompassSensorSimulator,self).__init__(**kw)  
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-    
+
     def initio(self, group, output,input, scenario, parms = None, **kw):
         """ Override since legacy interface
             
@@ -1152,16 +1107,6 @@ class LinearSalinitySimulator(deeding.LapseDeed):
         super(LinearSalinitySimulator,self).__init__(**kw)  
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-    
     def initio(self, group, output,input, depth, parms = None, **kw):
         """ Override since legacy interface
             
@@ -1303,17 +1248,6 @@ class SinusoidSalinitySimulator(deeding.LapseDeed):
         super(SinusoidSalinitySimulator,self).__init__(**kw)  
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-
-    
     def initio(self, group, output,input, parms = None, **kw):
         """ Override since legacy interface
             
@@ -1447,16 +1381,6 @@ class GradientSimulator(deeding.LapseDeed):
         super(GradientSimulator,self).__init__(**kw)  
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-    
     def initio(self, group, output, field, position, depth, parms = None, **kw):
         """ Override since legacy interface
             
